#!/usr/bin/env python
# -*- coding: utf-8 -*-

import pygame
from pygame.locals import *

from math import sin, cos, radians

VELOCIDAD = 5
INDICE_ROTACION = 3

class Tanque(pygame.sprite.RenderUpdates):
# Es un grupo de sprites

	def __init__(self, resolucion_monitor, JAMtank):

		pygame.sprite.RenderUpdates.__init__(self)
	
		self.resolucion_monitor = resolucion_monitor
		self.JAMtank = JAMtank # La clase principal del juego

		# Componentes
		self.base = Componente("Tanque.bmp", resolucion_monitor)
		self.add(self.base)

		self.haybala = False

	def evento(self, tecla):
	# pasa el evento a los componentes

		# Disparar.
		if tecla == K_LCTRL:
			if self.haybala == False:
				origen_disparo = (self.base.rect.center) # la punta del cañon
				self.JAMtank.crear_disparo(self, origen_disparo, self.base.angulo)
				self.haybala = False
		else:
			self.base.evento(tecla)

class Componente(pygame.sprite.Sprite):
# La base del tanque (las orugas) o la torreta.

	def __init__(self, imagen, resolucion_monitor):
		pygame.sprite.Sprite.__init__(self)

		self.ancho_monitor, self.alto_monitor = resolucion_monitor

		self.imagen_original = pygame.image.load(imagen).convert_alpha()

		self.image = self.imagen_original.copy()
		self.rect = self.image.get_rect() # get_bounding_rect()

		self.angulo = 0

		self.x = self.ancho_monitor / 2
		self.y = self.alto_monitor / 2

		self.dx, self.dy = self.get_vector(self.angulo) # distancia en x,y

		self.actualizar_posicion()

		self.get_info_rectangulo()

	def evento(self, tecla):
		# mandar girar, se suma o resta grados
		if tecla == K_RIGHT:
			self.angulo += int(0.7 * INDICE_ROTACION)
		    	self.image = pygame.transform.rotate(self.imagen_original, -self.angulo)
		elif tecla == K_LEFT:
			self.angulo -= int(0.7 * INDICE_ROTACION)
		    	self.image = pygame.transform.rotate(self.imagen_original, -self.angulo)

		# mandar mover, se calcula x e y segun la direccion de movimiento.
		if tecla == K_UP:
			self.dx, self.dy = self.get_vector(self.angulo)
			self.actualizar_posicion()
		elif tecla == K_DOWN:
			x, y = self.get_vector(self.angulo)
			self.dx = x * -1
			self.dy = y * -1
			self.actualizar_posicion()

	def get_vector(self, angulo):
	# Recibe un ángulo que da orientación al tanque
	# Devuelve el incremento de puntos x,y en su desplazamiento
		x = int(cos(radians(angulo)) * VELOCIDAD)
		y = int(sin(radians(angulo)) * VELOCIDAD)
		return x,y

	def actualizar_posicion(self):
	# cambia la posicion del rectangulo
	# Solo se ejecuta si el tanque se mueve hacia adelante o hacia atras
	# no se ejecuta cuando está girando en un mismo lugar

		x = self.x + self.dx
		y = self.y + self.dy

		if x > 0 and x < self.ancho_monitor and y > 0 and y < self.alto_monitor:
			self.x += self.dx
			self.y += self.dy
			self.rect.x = int(self.x) - self.rect.w / 2
			self.rect.y = int(self.y) - self.rect.h / 2

	def get_info_rectangulo(self):
		print " **** Rectangulo ****"
		print "Coordenada Superior Izquierda: %s,%s" % (self.rect.left, self.rect.top)
		print "Coordenada Inferior Derecha: %s,%s" % (self.rect.right, self.rect.bottom)
		print "Centro en pantalla: ", (self.rect.center)
		print "Radio en x: %s" % (self.rect.width / 2)
		print "Radio en y: %s" % (self.rect.height / 2)
		#print "Centro: ", (self.rect.centerx, self.rect.centery)
